{*****************************************}
{* Main unit for LogicGates9 application *}
{*****************************************}

unit logic9;

// Implementation of the interactive graphics:
//   - the circuit layout is constituted by a mixture of shapes and images
//   - the LEDs are colored ellipses; different color styles are used for on/off status
//   - the movement of the switches is done by changing the vertical position (TOP property) of the corresponding shapes
//   - the switch shapes being very small and difficult to click by the user, I used a transperant image, placed over them;
//     the OnClick event of the image is used to trigger the actions to be done when the corresponding switch has been clicked.

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, ExtCtrls, Menus, StdCtrls, nand1, nor1, nand2, nor2;

type
  {**********}
  { TfLogic9 }
  {**********}
  TfLogic9 = class(TForm)
    mLogic: TMainMenu;
    mGate, mGateExit, mHelp, mHelpAbout: TMenuItem;
    stTitle: TStaticText;
    Label1: TLabel;
    rbGate1, rbGate2, rbGate3, rbGate4: TRadioButton;
    procedure FormCreate(Sender: TObject);
    procedure mGateExitClick(Sender: TObject);
    procedure mHelpAboutClick(Sender: TObject);
    procedure rbGate1Change(Sender: TObject);
    procedure rbGate2Change(Sender: TObject);
    procedure rbGate3Change(Sender: TObject);
    procedure rbGate4Change(Sender: TObject);
  private
    iForm: Integer;
  end;

var
  fLogic9: TfLogic9;

implementation

{ Close the simulation window (specified by argument) }

procedure CloseForm(F: Integer);

begin
  case F of
    0: fNand1.Close;
    1: fNor1.Close;
    2: fNand2.Close;
    3: fNor2.Close;
  end;
end;

{$R *.lfm}

{**********}
{ TfLogic9 }
{**********}

{ Application start: Initialisation }

procedure TfLogic9.FormCreate(Sender: TObject);

begin
  iForm := -1;
end;

{ Menu item "Gate > Exit": Exit the application }

procedure TfLogic9.mGateExitClick(Sender: TObject);

begin
  CloseForm(iForm);
  Close;
end;

{ Menu item "Help > About": Display application about }

procedure TfLogic9.mHelpAboutClick(Sender: TObject);

var
  S: string;

begin
  S := 'Basic logic gates circuits:' + LineEnding;
  S += 'MOSFET NAND and NOR gates.' + LineEnding + LineEnding;
  S += 'Version 1.0, © allu, September 2022.';
  MessageDlg('About "LogicGates9"', S, mtInformation, [mbOK], 0);
end;

{ Simulation selection (radiobutton changes): Open corr. window and start the simulation }

procedure TfLogic9.rbGate1Change(Sender: TObject);

begin
  if rbGate1.Checked then begin
    CloseForm(iForm);                                                          // close actually open simulation window
    fNand1.Show;                                                               // open simulation window for user selection
    iForm := 0;
  end;
end;

procedure TfLogic9.rbGate2Change(Sender: TObject);

begin
  if rbGate2.Checked then
    CloseForm(iForm);
    fNor1.Show;
    iForm := 1;
end;

procedure TfLogic9.rbGate3Change(Sender: TObject);

begin
  if rbGate3.Checked then
    CloseForm(iForm);
    fNand2.Show;
    iForm := 2;
end;

procedure TfLogic9.rbGate4Change(Sender: TObject);

begin
  if rbGate4.Checked then
    CloseForm(iForm);
    fNor2.Show;
    iForm := 3;
end;

end.

